@@ -187,10 +187,10 @@ static void katalyzer_on_event(kate_stream *ks,const kate_event *ev)
 
   kprintf(ks,klt_misc,"An event was found\n");
 
-  kprintf(ks,klt_timing,"event start: %f (%llx)\n",ev->start_time,(long long)ev->start);
+  kprintf(ks,klt_timing,"event start: %f (%lld)\n",ev->start_time,(long long)ev->start);
   kprintf(ks,klt_timing,"event end: %f\n",ev->end_time);
-  kprintf(ks,klt_timing,"event duration: %f\n",ev->end_time-ev->start_time);
-  kprintf(ks,klt_timing,"event backlink: %f (%llx)\n",kate_granule_duration(ev->ki,ev->backlink),(long long)ev->backlink);
+  kprintf(ks,klt_timing,"event duration: %f (%lld)\n",ev->end_time-ev->start_time,(long long)ev->duration);
+  kprintf(ks,klt_timing,"event backlink: %f (%lld)\n",kate_granule_duration(ev->ki,ev->backlink),(long long)ev->backlink);
 
   kprintf(ks,klt_text,"Text encoding %d (%s)\n",ev->text_encoding,encoding2text(ev->text_encoding));
   kprintf(ks,klt_text,"Text language \"%s\" (%s)\n",ev->language?ev->language:ev->ki->language,ev->language?"overridden":"default");
@@ -246,7 +246,6 @@ static int ogg_parser_on_page(kate_uintptr_t data,ogg_page *og)
 {
   ogg_parser_data *opd=(ogg_parser_data*)data;
   ogg_packet op;
-  int eos=0;
   int ret;
   kate_stream *ks;
   int is_kate;
@@ -330,7 +329,6 @@ static int ogg_parser_on_page(kate_uintptr_t data,ogg_page *og)
         else if (ret>0) {
           /* we're done */
           kprintf(ks,klt_misc,"eof packet\n");
-          eos=1;
           break;
         }
         else {
@@ -494,7 +492,6 @@ int main(int argc,char **argv)
   int arg;
   char signature[64]; /* matches the size of the Kate ID header */
   size_t signature_size;
-  int raw;
   char *buffer=NULL;
   ogg_int64_t bytes;
   int headers_written=0;
@@ -581,8 +578,6 @@ int main(int argc,char **argv)
     }
     memcpy(buffer,signature,bytes);
 
-    raw=1;
-
     ret=kate_high_decode_init(&k);
     if (ret<0) {
       fprintf(stderr,"failed to init raw kate packet decoding (%d)\n",ret);
@@ -623,7 +618,6 @@ int main(int argc,char **argv)
     kate_free(buffer);
   }
   else {
-    raw=0;
     signature_size=bytes_read;
 
     init_ogg_parser_data(&opd);
