@@ -192,6 +192,11 @@ static kate_float hmsms2s(int h,int m,int s,int ms)
   return h*3600+m*60+s+ms/(kate_float)1000.0;
 }
 
+static kate_int64_t hmsms2ms(int h,int m,int s,int ms)
+{
+  return h*3600000+m*60000+s*1000+ms;
+}
+
 static char *fgets2(char *s,size_t len,FILE *f,int ignore_hash)
 {
   char *ret=fgets(s,len,f);
@@ -276,7 +281,47 @@ void update_stream_time(kate_state *k,FILE *fout,kate_float endt)
   }
 }
 
-static int convert_srt(FILE *fin,FILE *fout)
+static void remove_last_newline(char *text)
+{
+  size_t len;
+
+  len=strlen(text);
+  if (len>0 && text[len-1]=='\n') text[--len]=0;
+}
+
+static int emit_srt_event(FILE *fout,kate_int64_t t0,kate_int64_t t1,const char *text,int allow_srt_markup)
+{
+  ogg_packet op;
+  size_t len;
+  int ret;
+
+  update_stream_time(&k,fout,t0);
+
+  len=strlen(text);
+  ret=kate_text_validate(kate_utf8,text,len+1);
+  if (ret<0) {
+    if (ret==KATE_E_TEXT) {
+      fprintf(stderr,"Text is not valid UTF-8: %s\n",text);
+    }
+    else {
+      fprintf(stderr,"Failed to validate text: %d\n",ret);
+    }
+    return ret;
+  }
+  if (allow_srt_markup) kate_encode_set_markup_type(&k,kate_markup_simple);
+  ret=kate_ogg_encode_text_raw_times(&k,t0,t1,text,len,&op);
+  if (ret<0) {
+    fprintf(stderr,"Error encoding text: %d\n",ret);
+    return ret;
+  }
+  else {
+    ret=send_packet(fout,&op,t0);
+    if (ret<0) return ret;
+  }
+  return ret;
+}
+
+static int convert_srt(FILE *fin,FILE *fout,int allow_srt_markup)
 {
   enum { need_id, need_timing, need_text };
   int need = need_id;
@@ -285,7 +330,7 @@ static int convert_srt(FILE *fin,FILE *fout)
   int id;
   static char text[4096];
   int h0,m0,s0,ms0,h1,m1,s1,ms1;
-  kate_float t0=(kate_float)0,t1=(kate_float)0;
+  kate_int64_t t0=0,t1=0;
   int line=0;
 
   ret=flush_headers(fout);
@@ -338,8 +383,8 @@ static int convert_srt(FILE *fin,FILE *fout)
           return -1;
         }
         else {
-          t0=hmsms2s(h0,m0,s0,ms0);
-          t1=hmsms2s(h1,m1,s1,ms1);
+          t0=hmsms2ms(h0,m0,s0,ms0);
+          t1=hmsms2ms(h1,m1,s1,ms1);
           if (t1<t0) {
             fprintf(stderr,"Error at line %d: end time must not be less than start time\n",line);
             return -1;
@@ -349,32 +394,9 @@ static int convert_srt(FILE *fin,FILE *fout)
         break;
       case need_text:
         if (is_line_empty(str)) {
-          ogg_packet op;
-          size_t len;
-
-          update_stream_time(&k,fout,t0);
-
-          len=strlen(text);
-          if (len>0 && text[len-1]=='\n') text[--len]=0;
-          ret=kate_text_validate(kate_utf8,text,len+1);
-          if (ret<0) {
-            if (ret==KATE_E_TEXT) {
-              fprintf(stderr,"Text is not valid UTF-8: %s\n",text);
-            }
-            else {
-              fprintf(stderr,"Failed to validate text: %d\n",ret);
-            }
-            return ret;
-          }
-          ret=kate_ogg_encode_text(&k,t0,t1,text,strlen(text),&op);
-          if (ret<0) {
-            fprintf(stderr,"Error encoding text: %d\n",ret);
-            return ret;
-          }
-          else {
-            ret=send_packet(fout,&op,t0);
-            if (ret<0) return ret;
-          }
+          remove_last_newline(text);
+          ret=emit_srt_event(fout,t0,t1,text,allow_srt_markup);
+          if (ret<0) return ret;
           need=need_id;
         }
         else {
@@ -386,6 +408,15 @@ static int convert_srt(FILE *fin,FILE *fout)
     }
     fgets2(str,sizeof(str),fin,1);
   }
+
+  /* add any text we've accumulated if there's no empty line at the end */
+  if (need==need_text && text[0]) {
+    fprintf(stderr, "Warning: last event is not followed by an empty line - input might be truncated\n");
+    remove_last_newline(text);
+    ret=emit_srt_event(fout,t0,t1,text,allow_srt_markup);
+    if (ret<0) return ret;
+  }
+
   return 0;
 }
 
@@ -724,6 +755,7 @@ int main(int argc,char **argv)
   const char *arg;
   char *endptr;
   FILE *fin,*fout;
+  int allow_srt_markup=0;
 
   srand(time(NULL)^getpid());
   serial=rand();
@@ -762,6 +794,7 @@ int main(int argc,char **argv)
           printf("   -R <threshold>      Use repeat packets with given threshold (seconds)\n");
           printf("   -K <threshold>      Use keepalive packets with given threshold (seconds)\n");
           printf("   -C <tag>=<value>    Add comment to the Kate stream\n");
+          printf("   -M                  Allow simple markup in SRT files\n");
           exit(0);
         case 'o':
           if (!output_filename) {
@@ -836,6 +869,9 @@ int main(int argc,char **argv)
             exit(-1);
           }
           break;
+        case 'M':
+          allow_srt_markup=1;
+          break;
         default:
           fprintf(stderr,"Invalid option: %s\n",argv[n]);
           exit(-1);
@@ -920,7 +956,7 @@ int main(int argc,char **argv)
     ret=convert_kate(fin,fout);
   }
   else if (!strcmp(input_file_type,"srt")) {
-    ret=convert_srt(fin,fout);
+    ret=convert_srt(fin,fout,allow_srt_markup);
   }
   else if (!strcmp(input_file_type,"lrc")) {
     ret=convert_lrc(fin,fout);
